@@ -456,7 +456,7 @@ fn match_group_alias(group: &impl UnixGroup) -> impl Fn(&UserSpecifier) -> bool
     move |spec| match spec {
         UserSpecifier::User(ident) => match_group(group)(ident),
         /* the parser does not allow this, but can happen due to Runas_Alias,
-         * see https://github.com/memorysafety/sudo-rs/issues/13 */
+         * see https://github.com/trifectatechfoundation/sudo-rs/issues/13 */
         _ => {
             auth_warn!("warning: ignoring %group syntax in runas_alias for checking sudo -g");
             false
@@ -590,160 +590,159 @@ fn analyze(
         }
     }
 
-    impl Sudoers {
-        fn include(
-            &mut self,
-            parent: &Path,
-            path: &Path,
-            diagnostics: &mut Vec<Error>,
-            count: &mut u8,
-        ) {
-            if *count >= INCLUDE_LIMIT {
-                diagnostics.push(Error {
-                    source: Some(parent.to_owned()),
-                    location: None,
-                    message: format!("include file limit reached opening '{}'", path.display()),
-                })
-            // FIXME: this will cause an error in `visudo` if we open a non-privileged sudoers file
-            // that includes another non-privileged sudoer files.
-            } else {
-                match open_subsudoers(path) {
-                    Ok(subsudoer) => {
-                        *count += 1;
-                        self.process(path, subsudoer, diagnostics, count)
-                    }
-                    Err(e) => {
-                        let message = if e.kind() == io::ErrorKind::NotFound {
-                            // improve the error message in this case
-                            format!("cannot open sudoers file '{}'", path.display())
-                        } else {
-                            e.to_string()
-                        };
-
-                        diagnostics.push(Error {
-                            source: Some(parent.to_owned()),
-                            location: None,
-                            message,
-                        })
-                    }
+    fn include(
+        cfg: &mut Sudoers,
+        parent: &Path,
+        path: &Path,
+        diagnostics: &mut Vec<Error>,
+        count: &mut u8,
+    ) {
+        if *count >= INCLUDE_LIMIT {
+            diagnostics.push(Error {
+                source: Some(parent.to_owned()),
+                location: None,
+                message: format!("include file limit reached opening '{}'", path.display()),
+            })
+        // FIXME: this will cause an error in `visudo` if we open a non-privileged sudoers file
+        // that includes another non-privileged sudoer files.
+        } else {
+            match open_subsudoers(path) {
+                Ok(subsudoer) => {
+                    *count += 1;
+                    process(cfg, path, subsudoer, diagnostics, count)
                 }
-            }
-        }
-
-        fn process(
-            &mut self,
-            cur_path: &Path,
-            sudoers: impl IntoIterator<Item = basic_parser::Parsed<Sudo>>,
-            diagnostics: &mut Vec<Error>,
-            safety_count: &mut u8,
-        ) {
-            for item in sudoers {
-                match item {
-                    Ok(line) => match line {
-                        Sudo::LineComment => {}
-
-                        Sudo::Spec(permission) => self.rules.push(permission),
-
-                        Sudo::Decl(UserAlias(mut def)) => self.aliases.user.1.append(&mut def),
-                        Sudo::Decl(HostAlias(mut def)) => self.aliases.host.1.append(&mut def),
-                        Sudo::Decl(CmndAlias(mut def)) => self.aliases.cmnd.1.append(&mut def),
-                        Sudo::Decl(RunasAlias(mut def)) => self.aliases.runas.1.append(&mut def),
-
-                        Sudo::Decl(Defaults(params)) => {
-                            for (name, value) in params {
-                                self.set_default(name, value)
-                            }
-                        }
-
-                        Sudo::Include(path) => self.include(
-                            cur_path,
-                            &resolve_relative(cur_path, path),
-                            diagnostics,
-                            safety_count,
-                        ),
-
-                        Sudo::IncludeDir(path) => {
-                            if path.contains("%h") {
-                                diagnostics.push(Error{
-                                    source: Some(cur_path.to_owned()),
-                                    location: None,
-                                    message: format!("cannot open sudoers file {path}: percent escape %h in includedir is unsupported")});
-                                continue;
-                            }
-
-                            let path = resolve_relative(cur_path, path);
-                            let Ok(files) = std::fs::read_dir(&path) else {
-                                diagnostics.push(Error {
-                                    source: Some(cur_path.to_owned()),
-                                    location: None,
-                                    message: format!("cannot open sudoers file {}", path.display()),
-                                });
-                                continue;
-                            };
-                            let mut safe_files = files
-                                .filter_map(|direntry| {
-                                    let path = direntry.ok()?.path();
-                                    let text = path.file_name()?.to_str()?;
-                                    if text.ends_with('~') || text.contains('.') {
-                                        None
-                                    } else {
-                                        Some(path)
-                                    }
-                                })
-                                .collect::<Vec<_>>();
-                            safe_files.sort();
-                            for file in safe_files {
-                                self.include(cur_path, file.as_ref(), diagnostics, safety_count)
-                            }
-                        }
-                    },
-
-                    Err(basic_parser::Status::Fatal(pos, message)) => diagnostics.push(Error {
-                        source: Some(cur_path.to_owned()),
-                        location: Some(pos),
-                        message,
-                    }),
-                    Err(_) => panic!("internal parser error"),
-                }
-            }
-        }
-
-        fn set_default(&mut self, name: String, value: ConfigValue) {
-            match value {
-                Flag(value) => {
-                    if value {
-                        self.settings.flags.insert(name);
+                Err(e) => {
+                    let message = if e.kind() == io::ErrorKind::NotFound {
+                        // improve the error message in this case
+                        format!("cannot open sudoers file '{}'", path.display())
                     } else {
-                        self.settings.flags.remove(&name);
-                    }
-                }
-                List(mode, values) => {
-                    let slot: &mut _ = self.settings.list.entry(name).or_default();
-                    match mode {
-                        Mode::Set => *slot = values.into_iter().collect(),
-                        Mode::Add => slot.extend(values),
-                        Mode::Del => {
-                            for key in values {
-                                slot.remove(&key);
-                            }
-                        }
-                    }
-                }
-                Text(value) => {
-                    self.settings.str_value.insert(name, value);
-                }
-                Enum(value) => {
-                    self.settings.enum_value.insert(name, value);
-                }
-                Num(value) => {
-                    self.settings.int_value.insert(name, value);
+                        e.to_string()
+                    };
+
+                    diagnostics.push(Error {
+                        source: Some(parent.to_owned()),
+                        location: None,
+                        message,
+                    })
                 }
             }
         }
     }
 
+    fn process(
+        cfg: &mut Sudoers,
+        cur_path: &Path,
+        sudoers: impl IntoIterator<Item = basic_parser::Parsed<Sudo>>,
+        diagnostics: &mut Vec<Error>,
+        safety_count: &mut u8,
+    ) {
+        for item in sudoers {
+            match item {
+                Ok(line) => match line {
+                    Sudo::LineComment => {}
+
+                    Sudo::Spec(permission) => cfg.rules.push(permission),
+
+                    Sudo::Decl(UserAlias(mut def)) => cfg.aliases.user.1.append(&mut def),
+                    Sudo::Decl(HostAlias(mut def)) => cfg.aliases.host.1.append(&mut def),
+                    Sudo::Decl(CmndAlias(mut def)) => cfg.aliases.cmnd.1.append(&mut def),
+                    Sudo::Decl(RunasAlias(mut def)) => cfg.aliases.runas.1.append(&mut def),
+
+                    Sudo::Decl(Defaults(params)) => {
+                        for (name, value) in params {
+                            set_default(cfg, name, value)
+                        }
+                    }
+
+                    Sudo::Include(path) => include(
+                        cfg,
+                        cur_path,
+                        &resolve_relative(cur_path, path),
+                        diagnostics,
+                        safety_count,
+                    ),
+
+                    Sudo::IncludeDir(path) => {
+                        if path.contains("%h") {
+                            diagnostics.push(Error{
+                                    source: Some(cur_path.to_owned()),
+                                    location: None,
+                                    message: format!("cannot open sudoers file {path}: percent escape %h in includedir is unsupported")});
+                            continue;
+                        }
+
+                        let path = resolve_relative(cur_path, path);
+                        let Ok(files) = std::fs::read_dir(&path) else {
+                            diagnostics.push(Error {
+                                source: Some(cur_path.to_owned()),
+                                location: None,
+                                message: format!("cannot open sudoers file {}", path.display()),
+                            });
+                            continue;
+                        };
+                        let mut safe_files = files
+                            .filter_map(|direntry| {
+                                let path = direntry.ok()?.path();
+                                let text = path.file_name()?.to_str()?;
+                                if text.ends_with('~') || text.contains('.') {
+                                    None
+                                } else {
+                                    Some(path)
+                                }
+                            })
+                            .collect::<Vec<_>>();
+                        safe_files.sort();
+                        for file in safe_files {
+                            include(cfg, cur_path, file.as_ref(), diagnostics, safety_count)
+                        }
+                    }
+                },
+
+                Err(basic_parser::Status::Fatal(pos, message)) => diagnostics.push(Error {
+                    source: Some(cur_path.to_owned()),
+                    location: Some(pos),
+                    message,
+                }),
+                Err(_) => panic!("internal parser error"),
+            }
+        }
+    }
+
+    fn set_default(cfg: &mut Sudoers, name: String, value: ConfigValue) {
+        match value {
+            Flag(value) => {
+                if value {
+                    cfg.settings.flags.insert(name);
+                } else {
+                    cfg.settings.flags.remove(&name);
+                }
+            }
+            List(mode, values) => {
+                let slot: &mut _ = cfg.settings.list.entry(name).or_default();
+                match mode {
+                    Mode::Set => *slot = values.into_iter().collect(),
+                    Mode::Add => slot.extend(values),
+                    Mode::Del => {
+                        for key in values {
+                            slot.remove(&key);
+                        }
+                    }
+                }
+            }
+            Text(value) => {
+                cfg.settings.str_value.insert(name, value);
+            }
+            Enum(value) => {
+                cfg.settings.enum_value.insert(name, value);
+            }
+            Num(value) => {
+                cfg.settings.int_value.insert(name, value);
+            }
+        }
+    }
+
     let mut diagnostics = vec![];
-    result.process(path, sudoers, &mut diagnostics, &mut 0);
+    process(&mut result, path, sudoers, &mut diagnostics, &mut 0);
 
     let alias = &mut result.aliases;
     alias.user.0 = sanitize_alias_table(&alias.user.1, &mut diagnostics);
