@@ -420,8 +420,6 @@ impl User {
 pub struct Group {
     pub gid: GroupId,
     pub name: String,
-    pub passwd: String,
-    pub members: Vec<String>,
 }
 
 impl Group {
@@ -430,24 +428,9 @@ impl Group {
     /// In particular the grp.gr_mem pointer is assumed to be non-null, and pointing to a
     /// null-terminated list; the pointed-to strings are expected to be null-terminated.
     unsafe fn from_libc(grp: &libc::group) -> Group {
-        // find out how many members we have
-        let mut mem_count = 0;
-        while !(*grp.gr_mem.offset(mem_count)).is_null() {
-            mem_count += 1;
-        }
-
-        // convert the members to a slice and then put them into a vec of strings
-        let mut members = Vec::with_capacity(mem_count as usize);
-        let mem_slice = std::slice::from_raw_parts(grp.gr_mem, mem_count as usize);
-        for mem in mem_slice {
-            members.push(string_from_ptr(*mem));
-        }
-
         Group {
             gid: grp.gr_gid,
             name: string_from_ptr(grp.gr_name),
-            passwd: string_from_ptr(grp.gr_passwd),
-            members,
         }
     }
 
@@ -514,9 +497,7 @@ impl WithProcess {
 pub struct Process {
     pub pid: ProcessId,
     pub parent_pid: Option<ProcessId>,
-    pub group_id: ProcessId,
     pub session_id: ProcessId,
-    pub name: PathBuf,
 }
 
 impl Default for Process {
@@ -530,16 +511,10 @@ impl Process {
         Process {
             pid: Self::process_id(),
             parent_pid: Self::parent_id(),
-            group_id: Self::group_id(),
             session_id: Self::session_id(),
-            name: Self::process_name().unwrap_or_else(|| PathBuf::from("sudo")),
         }
     }
 
-    pub fn process_name() -> Option<PathBuf> {
-        std::env::args().next().map(PathBuf::from)
-    }
-
     /// Return the process identifier for the current process
     pub fn process_id() -> ProcessId {
         // NOTE libstd casts the `i32` that `libc::getpid` returns into `u32`
@@ -559,11 +534,6 @@ impl Process {
         }
     }
 
-    /// Return the process group id for the current process
-    pub fn group_id() -> ProcessId {
-        unsafe { libc::getpgid(0) }
-    }
-
     /// Get the session id for the current process
     pub fn session_id() -> ProcessId {
         unsafe { libc::getsid(0) }
@@ -672,6 +642,13 @@ pub fn escape_os_str_lossy(s: &std::ffi::OsStr) -> String {
     s.to_string_lossy().escape_default().collect()
 }
 
+pub fn make_zeroed_sigaction() -> libc::sigaction {
+    // SAFETY: since sigaction is a C struct, all-zeroes is a valid representation
+    // We cannot use a "literal struct" initialization method since the exact representation
+    // of libc::sigaction is not fixed, see e.g. https://github.com/trifectatechfoundation/sudo-rs/issues/829
+    unsafe { std::mem::zeroed() }
+}
+
 #[cfg(test)]
 mod tests {
     use std::{
@@ -747,9 +724,7 @@ mod tests {
                 },
                 Group {
                     name: name.to_string(),
-                    passwd: passwd.to_string(),
                     gid,
-                    members: mem.iter().map(|s| s.to_string()).collect(),
                 }
             )
         }
